pub enum RecvTimeoutError {
Timeout,
Disconnected,
}Expand description
Errors returned by the receiving methods of Receiver. Re-export from flume crate.
An error that may be emitted when attempting to wait for a value on a receiver with a timeout
when the receive operation times out or all senders are dropped and there are no values left
in the channel.
Variants
Timeout
A timeout occurred when attempting to receive a message.
Disconnected
All senders were dropped and no messages are waiting in the channel, so no further messages can be received.