TxtProperties

Struct TxtProperties 

pub struct TxtProperties { /* private fields */ }
Represents properties in a TXT record.

The key string of a property is case insensitive, and only one TxtProperty is stored for the same key.

RFC 6763: “A given key SHOULD NOT appear more than once in a TXT record.”

Implementations

Source

impl TxtProperties

pub fn new() -> Self

pub fn iter(&self) -> impl Iterator<Item = &TxtProperty>

Returns an iterator for all properties.

pub fn len(&self) -> usize

Returns the number of properties.

pub fn is_empty(&self) -> bool

Returns if the properties are empty.

pub fn get(&self, key: &str) -> Option<&TxtProperty>

Returns a property for a given key, where key is case insensitive.

pub fn get_property_val(&self, key: &str) -> Option<Option<&[u8]>>

Returns a property value for a given key, where key is case insensitive.

Returns None if key does not exist. Returns Some(Option<&u8>) for its value.

pub fn get_property_val_str(&self, key: &str) -> Option<&str>

Returns a property value string for a given key, where key is case insensitive.

Returns None if key does not exist. Returns Some("") if its value is None or is empty.

pub fn into_property_map_str(self) -> HashMap<String, String>

Consumes properties and returns a hashmap, where the keys are the properties keys.

If a property value is empty, return an empty string (because RFC 6763 allows empty values). If a property value is non-empty but not valid UTF-8, skip the property and log a message.